#line 2 "gengtype-lex.c"

#line 4 "gengtype-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 48
#define YY_END_OF_BUFFER 49
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[438] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   49,   36,
       33,   45,   36,   45,   34,   36,   36,   34,   34,   34,
       34,   34,   31,   10,   10,   31,   29,   31,   31,   31,
       20,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       10,   31,   41,   39,   46,   46,    0,   37,    0,    0,
        0,   38,   32,   34,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   34,   34,   34,   34,   34,   10,    0,
       25,    0,    0,    0,    0,    9,   20,   24,    0,    0,
        0,    0,    0,    0,    0,    0,   26,   11,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   10,    0,    0,    0,    0,   42,   44,   43,
       35,    0,    0,    0,    0,    0,    0,   34,   34,   34,
       34,   34,   34,   27,   28,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   30,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   34,
       34,   34,   34,   34,   34,    0,    0,    0,   13,    0,
       14,    0,    0,    0,    0,   22,   22,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,   34,   34,   34,   34,   34,   34,
        0,    0,    0,    0,    0,   17,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   34,   34,   34,   34,   34,    3,    0,    0,
        0,    0,   12,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   15,
        0,    0,    0,    0,    0,    0,    0,   34,    4,    5,
        2,   34,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,   16,    0,    0,    0,    0,   34,    1,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   22,   22,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       34,   34,   34,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   21,    0,    0,    0,    0,    0,    0,
       34,    7,    6,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   18,    0,    0,    0,   34,    0,    0,    0,
        0,    0,    0,    0,    0,   19,    0,    0,   47,   34,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       34,    0,    0,    0,    0,    0,    0,    0,    0,   34,

        0,   24,   24,    0,    0,    0,    0,    0,    0,    0,
       34,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    8,    0,   23,    0,    0,    0,    0,    0,
       40,    0,    0,    0,    0,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    6,    1,    7,    8,
        9,   10,    1,    6,    6,   11,   12,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,    6,    6,    6,
        6,    6,    1,    1,   14,   15,   16,   17,   18,   19,
       20,   21,   22,   23,   23,   24,   25,   26,   27,   28,
       23,   29,   30,   31,   32,   33,   34,   23,   35,   23,
       36,   37,   38,    1,   39,    1,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   49,   49,   50,   51,   52,
       53,   54,   49,   55,   56,   57,   58,   59,   49,   60,
       61,   62,    6,    6,    6,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[63] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    4,    5,
        1,    1,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    8,    1,    1,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9
    } ;

static yyconst flex_int16_t yy_base[476] =
    {   0,
        0,   38,   96,   12,   12,   13,   15,   16,  991, 1444,
     1444,   16,  953,  979,    0,  157,   19,  970,  927,  929,
      924,  932, 1444,   25,   27,   20, 1444,  946,  971,  971,
      967,  215,  253,    4,    7,   25,  952,   36,  925,  959,
        8,   31,   33,   37,   38,   32,   39,  133,  134,   40,
       66,  959,    0, 1444,  948,  947,  159, 1444,    0,  951,
      954, 1444, 1444,    0,  187,  162,  938,  895,  897,  892,
      900,  163,  907,  931,  892,   32,  894,  899,   77,  162,
     1444,  943,  938,  941,  932, 1444,  929, 1444,  914,  898,
      140,   54,  142,   43,  156,  886, 1444, 1444,  144,  148,

      143,  149,  151,  175,  158,  173,  152,  157,  184,  220,
      212,  221,  231,  921,  920,  291,    0, 1444, 1444, 1444,
     1444,  902,  863,  195,  865,  870,  872,  877,  871,  857,
      855,  868,  858, 1444, 1444,   64,  171,  213,  353,  215,
      391,  153,  349,  214,  244,  222,  245,  429,  241,  348,
      248,  247,  351,  355,  339,  350,  357,  340,  429, 1444,
        0,    0,  871,  865,  851,  849,  862,  852,  856,  870,
      832,  838,  843,  841,  831,  341,  258,  342, 1444,  346,
     1444,  352,  359,  491,  360, 1444,  528,  398,  392,  384,
      387,  418,  419,  421,  395,  477,    0,  849,  826,  832,

      837,  835,  825,  824,  857,  822,  831,  815,  827,  586,
      434,  399,  437,  159,  624, 1444,    0,  843,  841,  841,
      814,  819,  821,  797,  795,  323,  795,  478,  493,  483,
      481,  393,  394,  662,    0,  828,  793,  802,  786,  798,
        0,  797,  824,  700,  738,  776,  794, 1444,  254,  345,
      396,  432, 1444,  811,  809,  806,  782,  794,  774,  400,
      780,  778,  463,  774,  480,  499,  486,  487,  814, 1444,
        0,  813,    0,    0,    0,  783,  453,  788, 1444, 1444,
     1444,  852,  484,  509,  491,  520,  787,  794,  778,  758,
      752,  767,  766,  514,  758,  748,  750,  757,  752,  512,

      518,  513, 1444,    0,  760,    0,  539,  536, 1444,  527,
      385,  533,  538,  759,  776,  757,  738,  737, 1444,    0,
      736,  748,  752,  744,  524,  890,  545,    0,  585,  758,
      749,  928,  966,  535,  546,  553,  575,  757,  757,  736,
      726,  711,  528, 1444, 1004,    0,  743,    0,    0,  731,
      741, 1444, 1444,  582,  583,  588,  577,  555,  742,  734,
      740, 1042, 1444,    0,  737,  752,  732,  592,  591,  613,
      540,  594,  727,  718,  739, 1444,    0,  728, 1444,  738,
      621,  623,  622,  620,  624,  734,  722,  733,    0,  719,
      695,  626,  686,  618,  711,  710,  645,    0,  692,  630,

      651,  674,  677,  654,  711,  707,  695,  675,    0,  664,
     1080,  656,  712,  693,  714,  716,  669,  633,  617,  628,
        0,    0, 1444,  719, 1444,  721,  629,  593,  563,  530,
     1444,  443,  252,  191,  163,   62, 1444, 1118, 1127, 1136,
     1145, 1154, 1158, 1167, 1176, 1185, 1194, 1202, 1211, 1220,
     1229, 1238, 1247, 1256, 1265, 1273, 1282, 1290, 1298, 1306,
     1314, 1323, 1331, 1340, 1349, 1357, 1365, 1374, 1383, 1392,
     1400, 1409, 1417, 1426, 1435
    } ;

static yyconst flex_int16_t yy_def[476] =
    {   0,
      438,  438,  437,    3,  439,  439,  439,  439,  437,  437,
      437,  440,  441,  442,  443,  437,  437,  443,  443,  443,
      443,  443,  437,  437,  437,  444,  437,  445,  437,  437,
      437,  446,  446,   33,   33,   33,   33,   33,  447,  437,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
      437,  448,  449,  437,  450,  450,  440,  437,  440,  437,
      441,  437,  437,  443,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  443,  443,  443,  443,  443,  437,  444,
      437,  444,  437,  445,  437,  437,  437,  437,   33,   33,
       33,   33,   33,   33,   33,  447,  437,  437,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,  437,  448,  448,  437,  451,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  443,  443,  443,
      443,  443,  443,  437,  437,   33,   33,   33,  446,   33,
      446,   33,   33,   33,   33,   33,   33,  446,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,  116,  437,
      116,  452,  437,  437,  437,  437,  437,  437,  437,  443,
      443,  443,  443,  443,  443,   33,   33,   33,  437,   33,
      437,   33,   33,  446,   33,  437,  437,   33,   33,   33,
       33,   33,   33,   33,   33,   33,  453,  437,  437,  437,

      437,  437,  437,  437,  443,  443,  443,  443,  443,  443,
       33,   33,   33,   33,  446,  437,  187,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,   33,   33,   33,
       33,   33,   33,  446,  454,  437,  437,  437,  437,  437,
      455,  437,  443,  443,  443,  443,  443,  437,   33,   33,
       33,   33,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,   33,   33,   33,   33,  446,  437,
      456,  437,  457,  458,  459,  437,  437,  443,  437,  437,
      437,  443,   33,   33,   33,   33,  437,  437,  437,  437,
      437,  437,  437,  460,  437,  437,  437,  437,  437,   33,

       33,   33,  437,  461,  437,  462,  437,  443,  437,   33,
       33,   33,   33,  437,  437,  437,  437,  437,  437,  187,
      437,  437,  437,  437,   33,  446,   33,  463,  437,  437,
      443,  443,  443,   33,   33,   33,   33,  437,  437,  437,
      437,  437,   33,  437,  446,  464,  437,  465,  466,  437,
      443,  437,  437,   33,   33,   33,   33,   33,  437,  437,
      437,  446,  437,  467,  437,  437,  443,   33,   33,   33,
       33,   33,  437,  437,  437,  437,  468,  437,  437,  443,
       33,   33,   33,   33,   33,  437,  437,  437,  469,  437,
      443,   33,   33,   33,  437,  437,  437,  470,  437,  443,

       33,  437,  471,   33,  437,  437,  437,  437,  472,  437,
      443,   33,  437,  471,  471,  473,  437,  437,  437,  437,
      474,  475,  437,  437,  437,  473,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,    0,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437
    } ;

static yyconst flex_int16_t yy_nxt[1507] =
    {   0,
       10,   10,   11,   12,   10,   10,   13,   10,   10,   10,
       10,   14,   10,   51,   54,   54,   52,   54,   54,   58,
       72,   55,   55,   81,   56,   56,   79,   79,   79,   79,
       89,   91,   92,   89,   89,   10,   10,   10,   10,   16,
       11,   12,   17,   10,   13,   10,   10,   10,   10,   14,
       10,   89,   59,   95,   18,   93,   82,   89,   89,   89,
       99,   73,   89,   89,   89,   89,   89,  113,   79,   89,
      114,  130,  140,   10,   10,   10,  102,  100,   79,   79,
       89,   19,  106,  101,  105,  138,  131,  176,  103,  104,
       89,  112,  294,   20,   21,   22,   23,   24,   25,   26,

       23,   27,   28,   27,   27,   27,   29,   30,   31,   32,
       33,   34,   32,   35,   32,   36,   37,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   38,   32,
       32,   39,   40,   23,   32,   32,   41,   42,   43,   44,
       32,   32,   32,   45,   32,   46,   32,   47,   32,   48,
       32,   49,   32,   50,   32,   32,   32,   32,   65,   89,
       89,   66,   58,   72,   72,   81,   89,  137,   89,   89,
       89,  141,  107,   67,   89,   89,  139,   89,   89,   89,
      109,  110,   89,   89,   89,   89,  177,  143,   65,  108,
      111,   66,  252,  294,  144,   59,  142,   89,   82,   89,

       68,   89,  148,   67,   73,   73,  151,  145,  146,  149,
       89,  152,   69,   70,   71,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,  147,  150,  436,
       68,  148,  113,   79,  165,  114,  153,  178,   89,   89,
       89,   89,   69,   70,   71,  180,   89,   89,   89,  166,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,  154,  156,   89,  157,  182,
       89,   89,  184,   89,   89,  283,  158,  435,  212,   90,
       89,  155,  183,  185,   89,  190,  148,  189,   88,   88,
       88,  159,  159,  160,  159,  159,  159,  159,  159,  159,

      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  179,  179,  179,  179,  179,  179,  179,
      179,  179,  179,  179,  179,   89,   89,   89,   89,  262,
      263,   89,   89,  284,   89,   89,   89,   89,   89,  211,
      213,   89,  193,   89,  214,   89,   89,  196,  179,  179,
      179,  181,  181,  181,  181,  181,  181,  181,  181,  181,

      181,  181,  181,  148,  188,  191,  192,  194,  215,  195,
       89,   89,  250,   89,  335,  148,  148,  285,   89,   89,
       89,   89,   89,  230,   89,   89,  181,  181,  181,  186,
      187,  187,  186,  186,  186,  186,  186,  186,  186,  186,
      186,  228,  229,  148,   89,   89,  234,   89,  249,  148,
      269,  251,  293,  286,  307,  307,  294,  232,   89,  434,
       89,  231,  233,   89,  186,  186,  186,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  216,  216,  216,  216,  216,  216,  216,  216,  216,

      216,  216,  216,   89,   89,  266,   89,   89,  297,   89,
       89,  266,   89,   89,  310,  320,  320,   89,  300,   89,
      265,  312,  154,  148,  298,   89,  216,  216,  216,  217,
      217,  267,  268,  301,  302,   89,  313,  267,   89,   89,
      307,  307,  218,  219,   89,  334,   89,  311,  220,  331,
       89,  336,  327,   89,   89,  337,  354,  332,  330,   89,
      294,   89,  333,  333,   89,  325,   89,  355,  221,  222,
      223,   89,   89,  326,  356,  224,  372,  225,  384,   89,
      343,   89,  362,  226,  433,  227,  248,  248,  248,  248,
      248,  248,  248,  248,  248,  248,  248,  248,  347,  368,

      345,   89,  369,   89,  357,  370,  348,  371,   89,   89,
      432,  349,  349,  358,   89,  381,  382,   89,   89,  385,
       89,  248,  248,  248,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  383,  148,  393,   89,
      392,  394,  401,  404,   89,  294,   89,   89,   89,   89,
       89,  411,   89,  430,  148,  429,  411,  411,  428,  253,
      253,  253,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  407,  413,  413,   89,  415,  415,
       89,  414,   89,  408,  148,  422,  148,  402,  402,  412,
      422,  422,  427,  403,  415,  415,  420,  270,  270,  270,

      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,   89,  413,  413,  415,  415,  424,  424,  414,
      424,  424,  424,  424,  425,  419,  418,  425,  417,  425,
      410,  406,  405,  400,  399,  279,  279,  279,  280,  280,
      280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
      397,  396,  395,  391,  390,  388,  387,  386,  380,  379,
      378,  375,  374,  373,  367,  366,  365,  294,  294,  361,
      360,  359,  351,  280,  280,  280,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  350,  297,
      342,  341,  294,  294,  294,  340,  339,  338,  329,  324,

      323,  322,  321,  294,  318,  317,  294,  294,  316,  315,
      314,  281,  281,  281,  303,  303,  303,  303,  303,  303,
      303,  303,  303,  303,  303,  303,  308,  306,  305,  299,
      296,  295,  292,  291,  290,  289,  288,  287,  282,  278,
      277,  276,  275,  274,  273,  272,  264,  261,  260,  303,
      303,  303,  309,  309,  309,  309,  309,  309,  309,  309,
      309,  309,  309,  309,  259,  258,  257,  256,  255,  254,
      247,  246,  245,  244,  243,  242,  241,  240,  239,  238,
      237,  236,  210,  209,  208,  207,  206,  309,  309,  309,
      344,  344,  344,  344,  344,  344,  344,  344,  344,  344,

      344,  344,  205,  204,  203,  202,  201,  200,  199,  198,
      175,  174,  173,  172,  171,  170,  169,  168,  167,  164,
      163,  115,  115,   97,  136,  344,  344,  344,  352,  352,
      352,  352,  352,  352,  352,  352,  352,  352,  352,  352,
       89,   87,  135,  437,  134,  437,  133,  132,  129,  128,
      127,  126,  125,  124,  123,  122,  437,  121,  120,  119,
      115,   98,   97,  352,  352,  352,  353,  353,  353,  353,
      353,  353,  353,  353,  353,  353,  353,  353,   94,   87,
       86,   85,   84,   78,   77,   76,   75,   74,   63,   61,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,

      437,  353,  353,  353,  363,  363,  363,  363,  363,  363,
      363,  363,  363,  363,  363,  363,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  363,
      363,  363,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  376,  376,  376,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  437,  437,  437,  437,  437,  437,  437,  437,

      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  423,  423,  423,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   64,   64,  437,   64,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   89,   89,   89,   89,   89,
       89,   89,   89,   89,   96,   96,   96,   96,   96,   96,

       96,  437,   96,  116,  437,  437,  437,  437,  437,  437,
      116,  117,  117,  437,  117,  437,  117,  117,  117,  117,
      118,  118,  118,  118,  118,  118,  118,  118,  118,  162,
      162,  437,  162,  437,  162,  162,  162,  162,  197,  197,
      437,  197,  437,  197,  197,  197,  197,  235,  235,  437,
      235,  437,  235,  235,  235,  235,  271,  271,  437,  271,
      437,  271,  271,  271,  271,  248,  248,  248,  248,  248,
      437,  437,  248,  304,  304,  437,  304,  437,  304,  304,
      304,  304,  279,  279,  279,  279,  279,  437,  437,  279,
      280,  280,  280,  280,  280,  437,  437,  280,  281,  281,

      281,  281,  281,  437,  437,  281,  319,  319,  319,  319,
      319,  437,  437,  319,  328,  328,  437,  328,  437,  328,
      328,  328,  328,  309,  309,  309,  309,  309,  437,  437,
      309,  346,  346,  437,  346,  437,  346,  346,  346,  346,
      364,  364,  437,  364,  437,  364,  364,  364,  364,  352,
      352,  352,  352,  352,  437,  437,  352,  353,  353,  353,
      353,  353,  437,  437,  353,  377,  377,  437,  377,  437,
      377,  377,  377,  377,  389,  389,  437,  389,  437,  389,
      389,  389,  389,  398,  398,  437,  398,  437,  398,  398,
      398,  398,  409,  409,  437,  409,  437,  409,  409,  409,

      409,  416,  416,  437,  437,  437,  416,  437,  416,  421,
      421,  437,  421,  437,  421,  421,  421,  421,  426,  426,
      426,  437,  426,  426,  437,  426,  431,  431,  437,  431,
      437,  431,  431,  431,  431,  423,  423,  423,  423,  423,
      437,  437,  423,    9,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,

      437,  437,  437,  437,  437,  437
    } ;

static yyconst flex_int16_t yy_chk[1507] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    5,    6,    4,    7,    8,   12,
       17,    5,    6,   26,    7,    8,   24,   24,   25,   25,
       34,   34,   35,   35,   41,    1,    1,    1,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,   36,   12,   38,    2,   36,   26,   42,   46,   43,
       41,   17,   38,   44,   45,   47,   50,   51,   51,   94,
       51,   76,   94,    2,    2,    2,   43,   42,   79,   79,
       92,    2,   47,   42,   46,   92,   76,  136,   44,   45,
      136,   50,  436,    2,    2,    2,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,   16,   48,
       49,   16,   57,   66,   72,   80,   91,   91,   93,  101,
       99,   95,   48,   16,  100,  102,   93,  103,  107,  142,
       49,   49,   95,  108,  105,  214,  137,  100,   65,   48,
       49,   65,  214,  435,  101,   57,   99,  137,   80,  106,

       16,  104,  142,   65,   66,   72,  107,  102,  103,  105,
      109,  108,   16,   16,   16,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,  104,  106,  434,
       65,  104,  113,  113,  124,  113,  109,  138,  111,  138,
      144,  140,   65,   65,   65,  140,  110,  112,  146,  124,
       32,   32,   32,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,  110,  111,  149,  112,  144,
      145,  147,  146,  152,  151,  249,  112,  433,  177,   33,
      249,  110,  145,  147,  177,  152,  149,  151,   33,   33,
       33,  116,  116,  116,  116,  116,  116,  116,  116,  116,

      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  155,  158,  176,  178,  226,
      226,  250,  180,  250,  150,  143,  156,  153,  182,  176,
      178,  154,  155,  157,  180,  183,  185,  158,  139,  139,
      139,  141,  141,  141,  141,  141,  141,  141,  141,  141,

      141,  141,  141,  143,  150,  153,  154,  156,  182,  157,
      190,  311,  212,  191,  311,  183,  185,  251,  189,  232,
      233,  195,  251,  190,  188,  212,  141,  141,  141,  148,
      148,  148,  148,  148,  148,  148,  148,  148,  148,  148,
      148,  188,  189,  191,  192,  193,  195,  194,  211,  232,
      233,  213,  260,  252,  277,  277,  260,  193,  252,  432,
      211,  192,  194,  213,  148,  148,  148,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  159,  159,
      159,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  184,  184,  196,  228,  229,  265,  231,  263,  230,
      283,  266,  267,  268,  283,  294,  294,  285,  265,  229,
      228,  285,  196,  231,  263,  266,  184,  184,  184,  187,
      187,  229,  230,  267,  268,  284,  286,  266,  300,  302,
      307,  307,  187,  187,  301,  310,  286,  284,  187,  308,
      325,  312,  302,  310,  343,  313,  334,  308,  307,  312,
      430,  334,  308,  308,  313,  300,  371,  335,  187,  187,
      187,  327,  335,  301,  336,  187,  358,  187,  371,  336,
      325,  358,  343,  187,  429,  187,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  329,  354,

      327,  337,  355,  357,  337,  356,  329,  357,  354,  355,
      428,  329,  329,  337,  356,  368,  369,  369,  368,  372,
      372,  210,  210,  210,  215,  215,  215,  215,  215,  215,
      215,  215,  215,  215,  215,  215,  370,  381,  383,  370,
      382,  384,  392,  394,  394,  427,  384,  381,  383,  382,
      385,  400,  392,  420,  385,  419,  400,  400,  418,  215,
      215,  215,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,  397,  402,  402,  401,  403,  403,
      404,  402,  412,  397,  404,  410,  412,  393,  393,  401,
      410,  410,  417,  393,  414,  414,  408,  234,  234,  234,

      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  393,  413,  413,  415,  415,  416,  416,  413,
      424,  424,  426,  426,  416,  407,  406,  424,  405,  426,
      399,  396,  395,  391,  390,  244,  244,  244,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      388,  387,  386,  380,  378,  375,  374,  373,  367,  366,
      365,  361,  360,  359,  351,  350,  347,  342,  341,  340,
      339,  338,  331,  245,  245,  245,  246,  246,  246,  246,
      246,  246,  246,  246,  246,  246,  246,  246,  330,  324,
      323,  322,  321,  318,  317,  316,  315,  314,  305,  299,

      298,  297,  296,  295,  293,  292,  291,  290,  289,  288,
      287,  246,  246,  246,  269,  269,  269,  269,  269,  269,
      269,  269,  269,  269,  269,  269,  278,  276,  272,  264,
      262,  261,  259,  258,  257,  256,  255,  254,  247,  243,
      242,  240,  239,  238,  237,  236,  227,  225,  224,  269,
      269,  269,  282,  282,  282,  282,  282,  282,  282,  282,
      282,  282,  282,  282,  223,  222,  221,  220,  219,  218,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  175,  174,  173,  172,  171,  282,  282,  282,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,

      326,  326,  170,  169,  168,  167,  166,  165,  164,  163,
      133,  132,  131,  130,  129,  128,  127,  126,  125,  123,
      122,  115,  114,   96,   90,  326,  326,  326,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
       89,   87,   85,   84,   83,   82,   78,   77,   75,   74,
       73,   71,   70,   69,   68,   67,   61,   60,   56,   55,
       52,   40,   39,  332,  332,  332,  333,  333,  333,  333,
      333,  333,  333,  333,  333,  333,  333,  333,   37,   31,
       30,   29,   28,   22,   21,   20,   19,   18,   14,   13,
        9,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,  333,  333,  333,  345,  345,  345,  345,  345,  345,
      345,  345,  345,  345,  345,  345,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  345,
      345,  345,  362,  362,  362,  362,  362,  362,  362,  362,
      362,  362,  362,  362,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  362,  362,  362,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  411,  411,  411,  438,  438,
      438,  438,  438,  438,  438,  438,  438,  439,  439,  439,
      439,  439,  439,  439,  439,  439,  440,  440,  440,  440,
      440,  440,  440,  440,  440,  441,  441,  441,  441,  441,
      441,  441,  441,  441,  442,  442,  442,  442,  442,  442,
      442,  442,  442,  443,  443,    0,  443,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  447,  447,  447,  447,  447,  447,

      447,    0,  447,  448,    0,    0,    0,    0,    0,    0,
      448,  449,  449,    0,  449,    0,  449,  449,  449,  449,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  451,
      451,    0,  451,    0,  451,  451,  451,  451,  452,  452,
        0,  452,    0,  452,  452,  452,  452,  453,  453,    0,
      453,    0,  453,  453,  453,  453,  454,  454,    0,  454,
        0,  454,  454,  454,  454,  455,  455,  455,  455,  455,
        0,    0,  455,  456,  456,    0,  456,    0,  456,  456,
      456,  456,  457,  457,  457,  457,  457,    0,    0,  457,
      458,  458,  458,  458,  458,    0,    0,  458,  459,  459,

      459,  459,  459,    0,    0,  459,  460,  460,  460,  460,
      460,    0,    0,  460,  461,  461,    0,  461,    0,  461,
      461,  461,  461,  462,  462,  462,  462,  462,    0,    0,
      462,  463,  463,    0,  463,    0,  463,  463,  463,  463,
      464,  464,    0,  464,    0,  464,  464,  464,  464,  465,
      465,  465,  465,  465,    0,    0,  465,  466,  466,  466,
      466,  466,    0,    0,  466,  467,  467,    0,  467,    0,
      467,  467,  467,  467,  468,  468,    0,  468,    0,  468,
      468,  468,  468,  469,  469,    0,  469,    0,  469,  469,
      469,  469,  470,  470,    0,  470,    0,  470,  470,  470,

      470,  471,  471,    0,    0,    0,  471,    0,  471,  472,
      472,    0,  472,    0,  472,  472,  472,  472,  473,  473,
      473,    0,  473,  473,    0,  473,  474,  474,    0,  474,
        0,  474,  474,  474,  474,  475,  475,  475,  475,  475,
        0,    0,  475,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,  437,  437,  437,  437,  437,

      437,  437,  437,  437,  437,  437
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* -*- indented-text -*- */
/* Process source files and output type information.
   Copyright (C) 2002, 2003, 2004, 2005, 2007, 2008, 2009
   Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */
#define YY_NO_INPUT 1
#line 25 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
#include "bconfig.h"
#include "system.h"

#define malloc xmalloc
#define realloc xrealloc

#include "gengtype.h"

#define YY_DECL int yylex (const char **yylval)
#define yyterminate() return EOF_TOKEN

struct fileloc lexer_line;
int lexer_toplevel_done;

static void 
update_lineno (const char *l, size_t len)
{
  while (len-- > 0)
    if (*l++ == '\n')
      lexer_line.line++;
}


#line 983 "gengtype-lex.c"

#define INITIAL 0
#define in_struct 1
#define in_struct_comment 2
#define in_comment 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 59 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"

  /* Do this on entry to yylex():  */
  *yylval = 0;
  if (lexer_toplevel_done)
    {
      BEGIN(INITIAL);
      lexer_toplevel_done = 0;
    }

  /* Things we look for in skipping mode: */
#line 1180 "gengtype-lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 438 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 437 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 70 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return TYPEDEF;
}
	YY_BREAK
case 2:
/* rule 2 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 74 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return STRUCT;
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 78 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return UNION;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 82 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return EXTERN;
}
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 86 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return STATIC;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 91 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_OP;
}
	YY_BREAK
case 7:
/* rule 7 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 95 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_I;
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 99 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_ALLOC;
}
	YY_BREAK


case 9:
YY_RULE_SETUP
#line 107 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ BEGIN(in_struct_comment); }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 109 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ update_lineno (yytext, yyleng); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 110 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 112 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* don't care */
	YY_BREAK
case 13:
/* rule 13 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 113 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return GTY_TOKEN; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 114 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return VEC_TOKEN; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 115 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return UNION; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 116 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return STRUCT; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 117 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return ENUM; }
	YY_BREAK
case 18:
/* rule 18 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 118 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return PTR_ALIAS; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 10;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 119 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return NESTED_PTR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 120 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return NUM; }
	YY_BREAK
case 21:
/* rule 21 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 121 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  *yylval = XDUPVAR (const char, yytext, yyleng, yyleng+1);
  return PARAM_IS;
}
	YY_BREAK
case 22:
/* rule 22 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 127 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 127 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  size_t len;

  for (len = yyleng; ISSPACE (yytext[len-1]); len--)
    ;

  *yylval = XDUPVAR (const char, yytext, len, len+1);
  update_lineno (yytext, yyleng);
  return SCALAR;
}
	YY_BREAK
case 24:
/* rule 24 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 139 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  *yylval = XDUPVAR (const char, yytext, yyleng, yyleng+1);
  return ID;
}
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 144 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  *yylval = XDUPVAR (const char, yytext+1, yyleng-2, yyleng-1);
  return STRING;
}
	YY_BREAK
/* This "terminal" avoids having to parse integer constant expressions.  */
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 149 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  *yylval = XDUPVAR (const char, yytext+1, yyleng-2, yyleng-1);
  return ARRAY;
}
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 153 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  *yylval = XDUPVAR (const char, yytext+1, yyleng-2, yyleng);
  return CHAR;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 158 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return ELLIPSIS; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 159 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ return yytext[0]; }
	YY_BREAK
/* ignore pp-directives */
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 162 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{lexer_line.line++;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 164 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  error_at_line (&lexer_line, "unexpected character `%s'", yytext);
}
	YY_BREAK

case 32:
YY_RULE_SETUP
#line 169 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ BEGIN(in_comment); }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 170 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 34:
#line 172 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
case 35:
/* rule 35 can match eol */
#line 173 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 173 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 174 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ update_lineno (yytext, yyleng); }
	YY_BREAK
case 38:
/* rule 38 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 175 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK

case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 178 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 40:
#line 180 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
case 41:
YY_RULE_SETUP
#line 180 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 42:
/* rule 42 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 181 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK

case 43:
YY_RULE_SETUP
#line 183 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ BEGIN(INITIAL); } 
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 184 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{ BEGIN(in_struct); }
	YY_BREAK
case 45:
#line 187 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
case 46:
YY_RULE_SETUP
#line 187 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
{
  error_at_line (&lexer_line, 
		 "unterminated comment or string; unexpected EOF");
}
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 192 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 194 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1642 "gengtype-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(in_struct):
case YY_STATE_EOF(in_struct_comment):
case YY_STATE_EOF(in_comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 438 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 438 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 437);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 194 "/space/rguenther/gcc-4.5.4/gcc-4.5.4/gcc/gengtype-lex.l"



void
yybegin (const char *fname)
{
  yyin = fopen (fname, "r");
  if (yyin == NULL)
    {
      perror (fname);
      exit (1);
    }
  lexer_line.file = fname;
  lexer_line.line = 1;
}

void
yyend (void)
{
  fclose (yyin);
}

